Index: /code/branches/resource2/src/core/Identifier.cc
===================================================================
--- /code/branches/resource2/src/core/Identifier.cc	(revision 5689)
+++ /code/branches/resource2/src/core/Identifier.cc	(revision 5690)
@@ -138,5 +138,5 @@
         if (!this->bCreatedOneObject_ && Identifier::isCreatingHierarchy())
         {
-            // If no: We have to store the informations and initialize the Identifier
+            // If no: We have to store the information and initialize the Identifier
             COUT(4) << "*** ClassIdentifier: Register Class in " << this->getName() << "-Singleton -> Initialize Singleton." << std::endl;
             if (bRootClass)
Index: /code/branches/resource2/src/core/TclThreadManager.cc
===================================================================
--- /code/branches/resource2/src/core/TclThreadManager.cc	(revision 5689)
+++ /code/branches/resource2/src/core/TclThreadManager.cc	(revision 5690)
@@ -57,5 +57,5 @@
 
     /**
-        @brief A struct containing all informations about a Tcl-interpreter
+        @brief A struct containing all information about a Tcl-interpreter
     */
     struct TclInterpreterBundle
Index: /code/branches/resource2/src/network/ClientInformation.h
===================================================================
--- /code/branches/resource2/src/network/ClientInformation.h	(revision 5689)
+++ /code/branches/resource2/src/network/ClientInformation.h	(revision 5690)
@@ -49,5 +49,5 @@
 
   /**
-  * This class implements a list for client informations
+  * This class implements a list for client information
   * @author Oliver Scheuss
   */
Index: /code/branches/resource2/src/util/Debug.h
===================================================================
--- /code/branches/resource2/src/util/Debug.h	(revision 5689)
+++ /code/branches/resource2/src/util/Debug.h	(revision 5690)
@@ -29,5 +29,5 @@
 /**
     @file
-    @brief Handles different output-levels of errors, warnings, infos and debug informations.
+    @brief Handles different output-levels of errors, warnings, infos and debug information.
 
     The COUT(level) macro acts like std::cout, but the output is only performed if the given
@@ -45,8 +45,8 @@
      1: Errors
      2: Warnings
-     3: Informations
+     3: Information
      4: Debug information
      5: More debug information
-     6: Crazy debug informations
+     6: Crazy debug information
 
     @example

Index: /code/branches/resource2/src/core/ConfigValueContainer.h
===================================================================
--- /code/branches/resource2/src/core/ConfigValueContainer.h	(revision 5689)
+++ /code/branches/resource2/src/core/ConfigValueContainer.h	(revision 5690)
@@ -31,5 +31,5 @@
     @brief Definition of the ConfigValueContainer class.
 
-    The ConfigValueContainer class contains all needed informations about a configurable variable:
+    The ConfigValueContainer class contains all needed information about a configurable variable:
      - the name of the variable
      - the name of the class the variable belongs to
@@ -79,7 +79,7 @@
 
 
     //! The ConfigValuecontainer contains all needed informations about a configurable variable.
     /**
-        The ConfigValueContainer class contains all needed informations about a configurable variable:
+        The ConfigValueContainer class contains all needed information about a configurable variable:
          - the name of the variable
          - the name of the class the variable belongs to
@@ -79,7 +79,7 @@
 
 
-    //! The ConfigValuecontainer contains all needed informations about a configurable variable.
+    //! The ConfigValuecontainer contains all needed information about a configurable variable.
     /**
Index: /code/branches/resource2/src/core/Identifier.h
===================================================================
--- /code/branches/resource2/src/core/Identifier.h	(revision 5689)
+++ /code/branches/resource2/src/core/Identifier.h	(revision 5690)
@@ -31,5 +31,5 @@
     @brief Definition of the Identifier, ClassIdentifier and SubclassIdentifier classes, implementation of the ClassIdentifier and SubclassIdentifier classes.
 
-    The Identifier contains all needed informations about the class it belongs to:
+    The Identifier contains all needed information about the class it belongs to:
      - the name
      - a list with all objects
@@ -73,7 +73,7 @@
     // ###       Identifier        ###
     // ###############################
-    //! The Identifier is used to identify the class of an object and to store informations about the class.
-    /**
-        The Identifier contains all needed informations about the class it belongs to:
+    //! The Identifier is used to identify the class of an object and to store information about the class.
+    /**
+        The Identifier contains all needed information about the class it belongs to:
          - the name
          - a list with all objects
@@ -335,5 +335,5 @@
     /**
         ClassIdentifier is a Singleton, which means that only one object of a given type T exists.
-        This makes it possible to store informations about a class, sharing them with all
+        This makes it possible to store information about a class, sharing them with all
         objects of that class without defining static variables in every class.
 